==> westeros-1.0.0.tar.gz: westeros-1.0.0/westeros/auc/infrastructure/restart_process/auc.py <==
from robot.api import logger

from super_devops.unittest.unittest_wrapper import BaseUnitTest
from super_devops.ssh.paramiko_wrapper import BaseParamiko


class RestartProcessAUC(BaseUnitTest):
    def __init__(self, keyword, host, username, password, sudo_pw, process):
        super(RestartProcessAUC, self).__init__(
            keyword,
            method_name='test_restart'
        )
        self._host = host
        self._username = username
        self._password = password

        self._sudo_pw = sudo_pw
        self._process = process

        self._output = None

    def test_restart(self):
        cmd = "sudo service {} restart".format(self._process)
        logger.debug("cmd: {}".format(cmd))
        with BaseParamiko(
                self._host, self._username, self._password
        ) as ssh:
            self._output = ssh.exec_command(
                cmd, get_pty=True, sudo_pw=self._sudo_pw
            )
            logger.debug("output: {}".format(self._output))
        # Waiting for process started.
        import time
        time.sleep(5)
        # TODO: validate result

    def _validate_input(self):
        assert self._host is not None, 'Host is required.'
        assert self._username is not None, 'username is required.'
        assert self._password is not None, 'password is required.'
        assert self._sudo_pw is not None, 'sudo password is required.'
        assert self._process is not None, 'process is required.'

    def _validate_output(self):
        return self._output

==> westeros-1.1.0.tar.gz: westeros-1.1.0/westeros/auc/infrastructure/restart_process/auc.py <==
from robot.api import logger

from super_devops.robotframework.unittest_wrapper import BaseUnitTest
from super_devops.ssh.paramiko_wrapper import BaseParamiko


class RestartProcessAUC(BaseUnitTest):
    def __init__(self, keyword, host, username, password, sudo_pw, process):
        super(RestartProcessAUC, self).__init__(
            keyword,
            method_name='test_restart'
        )
        self._host = host
        self._username = username
        self._password = password

        self._sudo_pw = sudo_pw
        self._process = process

        self._output = None

    def test_restart(self):
        cmd = "sudo service {} restart".format(self._process)
        logger.debug("cmd: {}".format(cmd))
        with BaseParamiko(
                self._host, self._username, self._password
        ) as ssh:
            self._output, self._error = ssh.exec_command(
                cmd, get_pty=True, sudo_pw=self._sudo_pw
            )
            logger.debug("output: {}".format(self._output))
            logger.debug("error: {}".format(self._error))
        # TODO: validate process started.
        import time
        time.sleep(5)

    def _validate_input(self):
        assert self._host is not None, 'Host is required.'
        assert self._username is not None, 'username is required.'
        assert self._password is not None, 'password is required.'
        assert self._sudo_pw is not None, 'sudo password is required.'
        assert self._process is not None, 'process is required.'

    def _validate_output(self):
        return self._output
